from distutils.core import setup
from os import remove, listdir, path
for i in listdir(f'{path.dirname(__file__)}/dist'):
    remove(f'{path.dirname(__file__)}/dist/{i}')
setup(
    name = 'purePyStatistics',
    packages = ['pystatistics'],
    version = '0.1.7',
    license='MIT',
    description = 'Basic Functions for Statistics',
    author = 'Isaac To',
    author_email = 'isaacto3890@gmail.com',
    url = 'https://github.com/chisaku-dev/pyDataStats',
    keywords = ['statistics', 'data', 'probability'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
